@@ -9,10 +9,11 @@ __all__ = [
     'http',
     'io',
     'mqtt',
-    's3'
+    's3',
+    'websocket',
 ]
 
-__version__ = '1.0.0-dev'
+__version__ = '0.27.2'
 
 
 class NativeResource:
